@@ -47,13 +47,13 @@ class LAVAServerDispatcher(LavaDispatcher):
             parser_args['epilog'] = self.epilog
         self.parser = argparse.ArgumentParser(**parser_args)
         self.subparsers = self.parser.add_subparsers(
-                title="Sub-command to invoke")
+            title="Sub-command to invoke")
         prefixes = []
         if self.toolname is not None:
             prefixes.append(self.toolname)
         for prefix in prefixes:
             for entrypoint in pkg_resources.iter_entry_points(
-                "%s.commands" % prefix):
+                    "%s.commands" % prefix):
                 self.add_command_cls(entrypoint.load())
 
 
@@ -102,7 +102,7 @@ class manage(Command):
 
     def invoke(self):
         if self.args.production:
-            settings_module = "lava_server.settings.debian"
+            settings_module = "lava_server.settings.distro"
         else:
             settings_module = "lava_server.settings.development"
         if self.args.instance:
@@ -110,16 +110,13 @@ class manage(Command):
                 instance=self.args.instance)
             os.environ["DJANGO_DEBIAN_SETTINGS_TEMPLATE"] = ddst
         os.environ["DJANGO_SETTINGS_MODULE"] = settings_module
-        settings = __import__(settings_module, fromlist=[''])
-        # XXX execute_manager is deprecated in Django 1.4.
-        from django.core.management import execute_manager
-        execute_manager(settings, ['lava-server'] + self.args.command)
+        from django.core.management import execute_from_command_line
+        execute_from_command_line(['lava-server'] + self.args.command)
 
 
 def find_sources():
     base_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "..")
+        os.path.dirname(os.path.abspath(__file__)), "..")
     if os.path.exists(os.path.join(base_path, "lava_server")):
         sys.path.insert(0, base_path)
 
@@ -131,9 +128,9 @@ def main():
 def legacy_main():
     find_sources()
     settings_module = "lava_server.settings.development"
-    settings = __import__(settings_module, fromlist=[''])
-    from django.core.management import execute_manager
-    execute_manager(settings)
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", settings_module)
+    from django.core.management import execute_from_command_line
+    execute_from_command_line(sys.argv)
 
 
 if __name__ == "__main__":
