@@ -1,4 +1,4 @@
-# Copyright (C) 2010, 2011 Linaro Limited
+# Copyright (C) 2010-2013 Linaro Limited
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
@@ -17,6 +17,15 @@
 # along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.
 
 
+# WARNING:
+# Never edit this file on a production system!
+# Any changes can be overwritten at any time by upgrade or any
+# system management operation. All production config changes
+# should happen strictly to etc/settings.conf, etc. files.
+# All comments below are strictly for development usage and
+# reference.
+
+
 # Administrator contact, used for sending
 # emergency email when something breaks
 ADMINS = (
@@ -50,7 +59,6 @@ USE_L10N = True
 TEMPLATE_LOADERS = (
     'django.template.loaders.filesystem.Loader',
     'django.template.loaders.app_directories.Loader',
-#     'django.template.loaders.eggs.Loader',
 )
 
 MIDDLEWARE_CLASSES = [
@@ -105,21 +113,22 @@ LOGIN_URL = MOUNT_POINT + "/accounts/login/"
 INSTALLED_APPS = [
     'django.contrib.auth',
     'django.contrib.contenttypes',
-    'django.contrib.markup',
     'django.contrib.sessions',
     'django.contrib.sites',
     'django.contrib.humanize',
     'django_openid_auth',
     'django_tables2',
-    'staticfiles',
+    'django.contrib.staticfiles',
     # Uncomment the next line to enable the admin:
     'django.contrib.admin',
     # Uncomment the next line to enable admin documentation:
     # 'django.contrib.admindocs',
     # Admin docs disabled due to: https://code.djangoproject.com/ticket/6681
+    'longerusername',
     'linaro_django_xmlrpc',
     'lava_markitup',  # Support app for MarkItUp in LAVA
     'south',
+    'google_analytics',
 ]
 
 try:
@@ -134,19 +143,22 @@ TEMPLATE_CONTEXT_PROCESSORS = [
     "django.core.context_processors.i18n",
     "django.core.context_processors.media",
     "django.core.context_processors.request",
-    "staticfiles.context_processors.static_url",
+    "django.core.context_processors.static",
     "lava_server.context_processors.lava",
     "lava_server.context_processors.openid_available",
 ]
 
 
 AUTHENTICATION_BACKENDS = (
+    # Uncomment CrowdRestBackend and comment OpenIDBackend to enable
+    # Atlassian Crowd auth.
+    # 'crowdrest.backend.CrowdRestBackend',
     'django_openid_auth.auth.OpenIDBackend',
     'django.contrib.auth.backends.ModelBackend',
 )
 
 OPENID_CREATE_USERS = True
-OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO = True
+OPENID_LAUNCHPAD_TEAMS_MAPPING_AUTO = False
 OPENID_UPDATE_DETAILS_FROM_SREG = True
 OPENID_SSO_SERVER_URL = 'https://login.ubuntu.com/'
 
@@ -156,12 +168,14 @@ oidutil.log = lambda msg, level=0: None
 
 RESTRUCTUREDTEXT_FILTER_SETTINGS = {"initial_header_level": 4}
 
-# Skip south tests as they seem to break everything else.
-# This is fixed in south 0.7.1, if we upgrade past that it's safe to
-# remove this line.
-SKIP_SOUTH_TESTS = True
+# Add google analytics model.
+GOOGLE_ANALYTICS_MODEL = True
 
 ME_PAGE_ACTIONS = [
     ("django.contrib.auth.views.password_change", "Change your password"),
     ("django.contrib.auth.views.logout", "Sign out"),
-    ]
+]
+
+ALLOWED_HOSTS = ['*']
+
+SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
